@@ -6,7 +6,7 @@ Rubric::User - a Rubric user
 
 =head1 VERSION
 
- $Id: /my/cs/projects/rubric/trunk/lib/Rubric/User.pm 18100 2006-01-26T13:59:16.285684Z rjbs  $
+ $Id: User.pm,v 1.18 2005/01/23 20:00:24 rjbs Exp $
 
 =head1 DESCRIPTION
 
@@ -18,7 +18,6 @@ Rubric::DBI, which is a Class::DBI class.
 use strict;
 use warnings;
 use base qw(Rubric::DBI);
-use Digest::MD5 qw(md5_hex);
 use Time::Piece;
 
 __PACKAGE__->table('users');
@@ -36,7 +35,7 @@ __PACKAGE__->table('users');
 =cut
 
 __PACKAGE__->columns(
-	All => qw(username password email created verification_code reset_code)
+	All => qw(username password email created verification_code)
 );
 
 =head1 RELATIONSHIPS
@@ -57,8 +56,8 @@ number of accessors for his tag list.
 
 =head3 tags
 
-This returns an arrayref of all the user's (non-system) tags in their database
-colation order.
+This returns an arrayref of all the user's tags in their database colation
+order.
 
 =cut
 
@@ -66,13 +65,12 @@ __PACKAGE__->set_sql(tags => <<'' );
 SELECT DISTINCT tag
 FROM entrytags
 WHERE entry IN (SELECT id FROM entries WHERE user = ?)
-  AND tag NOT LIKE '@%%'
 ORDER BY tag
 
 sub tags {
 	my ($self) = @_;
 	my $sth = $self->sql_tags;
-	$sth->execute($self->username);
+	$sth->execute($self);
 	my $tags = $sth->fetchall_arrayref;
 	[ map { @$_ } @$tags ];
 }
@@ -89,14 +87,13 @@ __PACKAGE__->set_sql(tags_counted => <<'' );
 SELECT DISTINCT tag, COUNT(*) AS count
 FROM entrytags
 WHERE entry IN (SELECT id FROM entries WHERE user = ?)
-  AND tag NOT LIKE '@%%'
 GROUP BY tag
 ORDER BY tag
 
 sub tags_counted {
 	my ($self) = @_;
 	my $sth = $self->sql_tags_counted;
-	$sth->execute($self->username);
+	$sth->execute($self);
 	my $tags = $sth->fetchall_arrayref;
 	return $tags;
 }
@@ -110,21 +107,21 @@ tags.  Tags are related if they occur together on entries.
 
 sub related_tags {
 	my ($self, $tags) = @_;
-  $tags = [ keys %$tags ] if ref $tags eq 'HASH';
 	return unless $tags and my @tags = @$tags;
 
-	my $query = q|
+	my $query = "
 	SELECT DISTINCT tag FROM entrytags
-	WHERE entry IN (SELECT id FROM entries WHERE user = ?)
-    AND tag NOT IN (| . join(',',map { $self->db_Main->quote($_) } @tags) . q|)
-    AND tag NOT LIKE '@%'
-	  AND | .
+	WHERE entry IN (SELECT id FROM entries WHERE user = ?) AND 
+	tag NOT IN (" . join(',',map { $self->db_Main->quote($_) } @tags) . ")
+	AND ";
+
+	$query .= 
 		join ' AND ',
 		map { "entry IN (SELECT entry FROM entrytags WHERE tag=$_)" }
 		map { $self->db_Main->quote($_) }
 		@tags;
 
-	$self->db_Main->selectcol_arrayref($query, undef, $self->username);
+	my $result = $self->db_Main->selectcol_arrayref($query, undef, $self);
 }
 
 =head3 related_tags_counted(\@tags)
@@ -136,25 +133,23 @@ returns an arrayref of arrayrefs, each a pair of tag/occurance values.
 
 sub related_tags_counted {
 	my ($self, $tags) = @_;
-  return unless $tags;
-  $tags = [ keys %$tags ] if ref $tags eq 'HASH';
-	return unless my @tags = @$tags;
+	return unless $tags and my @tags = @$tags;
 
-	my $query = q|
+	my $query = "
 		SELECT DISTINCT tag, COUNT(*) AS count
 		FROM entrytags
-		WHERE entry IN (SELECT id FROM entries WHERE user = ?)
-    AND tag NOT IN (| . join(',',map { $self->db_Main->quote($_) } @tags) . q|)
-		AND tag NOT LIKE '@%'
-    AND | .
+		WHERE entry IN (SELECT id FROM entries WHERE user = ?) AND 
+		tag NOT IN (" . join(',',map { $self->db_Main->quote($_) } @tags) . ")
+		AND ";
+
+	$query .= 
 		join ' AND ',
 		map { "entry IN (SELECT entry FROM entrytags WHERE tag=$_)" }
 		map { $self->db_Main->quote($_) }
 		@tags;
-
 	$query .= " GROUP BY tag";
 
-	$self->db_Main->selectall_arrayref($query, undef, $self->username);
+	my $result = $self->db_Main->selectall_arrayref($query, undef, $self);
 }
 
 =head1 INFLATIONS
@@ -179,7 +174,7 @@ sub _create_times {
 
 =head2 quick_entry(\%entry)
 
-This method creates or updates an entry for the user.  The passed entry should
+This method creates or udpates an entry for the user.  The passed entry should
 include the following data:
 
  uri         - the URI for the entry
@@ -202,19 +197,15 @@ sub quick_entry {
 	return unless $entry->{title};
 	$entry->{tags} = Rubric::Entry->tags_from_string($entry->{tags});
 
-	my $link;
-	if ($entry->{uri}) {
-		$link = eval { Rubric::Link->find_or_create({ uri => $entry->{uri} }) };
-		return unless $link;
-	}
+	my $link = Rubric::Link->find_or_create({ uri => $entry->{uri} })
+		if $entry->{uri};
 
 	my $new_entry = $entry->{entryid}
 		? Rubric::Entry->retrieve($entry->{entryid})
-		: $link
+		: $entry->{uri}
 			? Rubric::Entry->find_or_create({ link => $link, user => $self })
 			: Rubric::Entry->create({ user => $self });
 
-	$new_entry->link($link);
 	$new_entry->title($entry->{title});
 	$new_entry->description($entry->{description});
 	$new_entry->body($entry->{body} || undef);
@@ -244,82 +235,6 @@ sub verify {
 	return;
 }
 
-=head2 reset_password($code)
-
-If the given code matches this user's C<reset_code>, the user's password will be
-reset via C<randomize_password> and his reset code will be undefined.  If
-successful, the new password is returned.  Otherwise, the routine returns
-false.
-
-=cut
-
-sub reset_password {
-	my ($self, $code) = @_;
-
-	return unless $self->reset_code;
-
-	if ($code and $code eq $self->reset_code) {
-		my $password = $self->randomize_password;
-		$self->reset_code(undef);
-		$self->update;
-		return $password;
-	}
-	return;
-}
-
-=head2 randomize_password
-
-This method resets the user's password to a pseudo-random string and returns
-the new password.
-
-=cut
-
-sub __random_string {
-	my $length = 15;
-	my @legal  = ('a'..'z', 'A'..'Z', 0..9);
-	my $string = join '', map { @legal[rand @legal] } 1 .. $length;
-
-	return wantarray ? (md5_hex($string), $string) : md5_hex($string);
-}
-
-sub randomize_password {
-	my ($self) = @_;
-	my ($pass_md5, $password) = $self->__random_string;
-	
-	$self->password($pass_md5);
-	$self->update;
-
-	return $password;
-}
-
-=head2 randomize_reset_code
-
-This method resets the user's reset code to the md5sum of a pseudo-random
-string.
-
-=cut
-
-sub randomize_reset_code {
-	my ($self) = @_;
-	my $reset_code = $self->__random_string;
-	$self->reset_code($reset_code);
-	$self->update;
-}
-
-=head2 randomize_verification_code
-
-This method resets the user's verification code to the md5sum of a
-pseudo-random string.
-
-=cut
-
-sub randomize_verification_code {
-	my ($self) = @_;
-	my $verification_code = $self->__random_string;
-	$self->verification_code($verification_code);
-	$self->update;
-}
-
 =head1 TODO
 
 =head1 AUTHOR
